==> webkit2gtk_2.20.5.orig.tar.xz: webkitgtk-2.20.5/Source/JavaScriptCore/dfg/DFGInsertionSet.cpp <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "DFGInsertionSet.h"

#if ENABLE(DFG_JIT)

namespace JSC { namespace DFG {

void InsertionSet::insertSlow(const Insertion& insertion)
{
    ASSERT(!m_insertions.isEmpty());
    ASSERT(m_insertions.last().index() > insertion.index());
    
    for (size_t index = m_insertions.size() - 1; index--;) {
        if (m_insertions[index].index() <= insertion.index()) {
            m_insertions.insert(index + 1, insertion);
            return;
        }
    }

    m_insertions.insert(0, insertion);
}

size_t InsertionSet::execute(BasicBlock* block)
{
    return executeInsertions(*block, m_insertions);
}

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)

==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/JavaScriptCore/dfg/DFGInsertionSet.cpp <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "DFGInsertionSet.h"

#if ENABLE(DFG_JIT)

#include "JSCJSValueInlines.h"

namespace JSC { namespace DFG {

void InsertionSet::insertSlow(const Insertion& insertion)
{
    ASSERT(!m_insertions.isEmpty());
    ASSERT(m_insertions.last().index() > insertion.index());
    
    for (size_t index = m_insertions.size() - 1; index--;) {
        if (m_insertions[index].index() <= insertion.index()) {
            m_insertions.insert(index + 1, insertion);
            return;
        }
    }

    m_insertions.insert(0, insertion);
}

size_t InsertionSet::execute(BasicBlock* block)
{
    return executeInsertions(*block, m_insertions);
}

Node* InsertionSet::insertConstant(size_t index, NodeOrigin origin, FrozenValue* value, NodeType op)
{
    return insertNode(index, speculationFromValue(value->value()), op, origin, OpInfo(value));
}

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)
